# Code of Conduct

The [Curtin Open Knowledge Initiative (COKI)](https://openknowledge.community/) is dedicated to providing a welcoming and supportive environment for all people, regardless of background or identity. By participating in the activities of the COKI community, participants accept to abide by [The COKI Code of Conduct](https://openknowledge.community/about-coki/code-of-conduct/) and accept the procedures by which any Code of Conduct incidents are resolved.

Please refer to [The COKI Code of Conduct on our website](https://openknowledge.community/about-coki/code-of-conduct/) for further details.
